Method: Aef::Init.default_command
- Defined in:
- lib/aef/init.rb
.default_command(command = false) ⇒ Object
Note:
This used to be implicitly set to “restart” but in practice caused far too much unwanted service restarts, so it is now not enabled by default.
The default command to be called if no command is specified on the commandline.
56 57 58 59 60 61 62 |
# File 'lib/aef/init.rb', line 56 def default_command(command = false) if command.equal?(false) @default_command else @default_command = command.to_sym end end |